@@ -1,7 +1,9 @@
 from linkml_runtime.loaders.json_loader import JSONLoader
 from linkml_runtime.loaders.rdf_loader import RDFLoader
 from linkml_runtime.loaders.yaml_loader import YAMLLoader
+from linkml_runtime.loaders.csv_loader import CSVLoader
 
 json_loader = JSONLoader()
 rdf_loader = RDFLoader()
 yaml_loader = YAMLLoader()
+csv_loader = CSVLoader()
